from __future__ import annotations
import typing

import numpy as np

class InstanceTranslator:
    @staticmethod
    def instance_translate(
            instance_data: dict[
                str,
                typing.Union[
                    int,
                    float,
                    np.integer,
                    np.floating,
                    np.ndarray,
                    list
                ]
            ]
            ) -> dict[str, typing.Union[int, float, list]]:
        translated_instance_data = {
                key: InstanceTranslator.__instance_translate(instance_data_value = value)
                for key, value in instance_data.items()
                }
        return translated_instance_data

    @staticmethod
    def __instance_translate(
            *,
            instance_data_value: typing.Union[int, float, np.integer, np.floating, np.ndarray, list]
            ) -> typing.Union[int, float, list]:
        if isinstance(instance_data_value, np.ndarray):
            return instance_data_value.tolist()
        elif isinstance(instance_data_value, list):
            return [
                InstanceTranslator.__instance_translate(instance_data_value=value)
                for value in instance_data_value
            ]
        else:
            return InstanceTranslator.__numpy_translate(value=instance_data_value)

    @staticmethod
    def __numpy_translate(
        *, value: typing.Union[int, float, np.integer, np.floating, np.ndarray]
    ) -> typing.Union[int, float]:
        if isinstance(value, (int, float)):
            return value
        elif isinstance(value, np.integer):
            return int(value)
        elif isinstance(value, np.floating):
            return float(value)
        else:
            raise TypeError(f"{value} is {type(value)} type, not number.")
