from __future__ import annotations

from typing import Any

import jijmodeling as jm

from jijmodeling.sampleset import Evaluation, MeasuringTime, Record

from jijzept.response.base import BaseResponse


class JijModelingResponse(BaseResponse, jm.SampleSet):
    """Return object from JijZept.

    This class inherits from `jijmodeling.sampleset.SampleSet`.
    """

    @classmethod
    def from_json_obj(cls, json_obj) -> Any:
        """Generate object from JSON object.

        Args:
            json_obj (str): JSON object

        Returns:
            Any: object
        """
        response = cls.from_serializable(json_obj)
        return response

    @classmethod
    def empty_data(cls) -> Any:
        return cls(
            record=Record({"x": []}, [0]),
            evaluation=Evaluation([]),
            measuring_time=MeasuringTime(),
        )

    def __repr__(self):
        return jm.SampleSet.__repr__(self)

    def __str__(self):
        return BaseResponse.__repr__(self) + "\n" + jm.SampleSet.__str__(self)

    def set_variable_labels(self, var_labels: dict[int, str]):
        self._variable_labels = var_labels

    @property
    def variable_labels(self) -> dict[int, str]:
        return self._variable_labels
